/**
 * Copyright (C) 2017 INRIA  http://www.inria.fr
 * Copyright (C) 2017 CNRS   http://www.cnrs.fr
 *
 * Authors:
 *  Nicolas Holzschuch:  nicolas.holzschuch@inria.fr
 *  Romain  Pacanowski:  romain.pacanowski@institutoptique.fr 
 *
 * Permission to use, copy and modify this software and its documentation without
 * fee for educational, research and non-profit purposes, is hereby granted, provided
 * that the above copyright notice appear in all copies.
 * 
 * To request permission to incorporate this software into commercial products contact
 * the authors above. 
 */

#include <iostream>
#include <fstream>
#include <assert.h>
#include <gsl/gsl_fit.h>
#include <gsl/gsl_statistics.h>
#include <gsl/gsl_sf.h>

// Code for computing the distribution constant (p * gamma_inv(1/p) / pi) 
// Requires GNU Scientific Library (GSL)
// Compile with:  g++ -I/usr/local/include computeRenormalization.cpp -lm -L/usr/local/lib -lgsl 
// (if GSL is installed in /usr/local, adapt to your own situation)
//
// Execute with: ./a.out


const int numSamples=256;

int main() {
  std::string outData("ctd_distributionConstant.h");
  std::fstream fs;
  fs.open (outData, std::fstream::out);
	
  fs << "const Float distributionConstant[" << numSamples << "] = {";
  for (int kp = 0; kp < numSamples; kp++) {
  	  double p = 5.0 * (double)kp/numSamples;
  	  if (kp == 0) 
  	  	  fs << 0.0 ;
	  else 
	  	  fs << p * gsl_sf_gammainv(1./p)/ M_PI ;
	  if (kp < numSamples - 1) fs << ", ";
  }
  fs << "};";
  fs.close();
}
